@@ -19,8 +19,11 @@ test_that("simple Shiny app bundle includes correct files", {
   bundleTempDir <- makeShinyBundleTempDir("simple_shiny", "shinyapp-simple",
                                           NULL)
   on.exit(unlink(bundleTempDir, recursive = TRUE))
+  # listBundleFiles only includes "user" files and ignores
+  # generated files like the packrat and manifest data.
   files <- listBundleFiles(bundleTempDir)
-  expect_identical(files$contents, c("manifest.json", "server.R", "ui.R"))
+  expect_identical(files$contents, c("server.R", "ui.R"))
+  expect_identical(list.files(bundleTempDir), c("manifest.json", "packrat", "server.R", "ui.R"))
 })
 
 test_that("simple Shiny app bundle is runnable", {
@@ -105,6 +108,8 @@ test_that("Rmd with reticulate as a dependency includes python in the manifest",
 
   python <- Sys.which("python")
   skip_if(python == "", "python is not installed")
+  pipMissing <- system2(python, "-m pip help", stdout = NULL, stderr = NULL)
+  skip_if(pipMissing != 0, "pip module is not installed")
 
   bundleTempDir <- makeShinyBundleTempDir("reticulated rmd", "test-reticulate-rmds",
                                           NULL, python = python)
@@ -126,6 +131,8 @@ test_that("Rmd with reticulate as an inferred dependency includes reticulate and
 
   python <- Sys.which("python")
   skip_if(python == "", "python is not installed")
+  pipMissing <- system2(python, "-m pip help", stdout = NULL, stderr = NULL)
+  skip_if(pipMissing != 0, "pip module is not installed")
 
   bundleTempDir <- makeShinyBundleTempDir("reticulated rmd", "test-reticulate-rmds",
                                           "implicit.Rmd", python = python)
@@ -141,34 +148,57 @@ test_that("Rmd with reticulate as an inferred dependency includes reticulate and
   expect_true(file.exists(file.path(bundleTempDir, manifest$python$package_manager$package_file)))
 })
 
-test_that("Rmd with reticulate but no python is an error", {
+test_that("getPython handles null python by checking RETICULATE_PYTHON", {
   skip_on_cran()
-  expect_error(makeShinyBundleTempDir("reticulated rmd", "test-reticulate-rmds", NULL), "*python was not specified")
-})
 
-test_that("Rmd with reticulate but no python is an error", {
-  skip_on_cran()
-  expect_error(makeShinyBundleTempDir("reticulated rmd", "test-reticulate-rmds", "implicit.Rmd"), "*python was not specified")
-})
-
-test_that("Rmd with reticulate can use python specified in RETICULATE_PYTHON environment variable", {
-  skip_on_cran()
-  skip_if_not_installed("reticulate")
-
-  python <- Sys.which("python")
-  Sys.setenv(RETICULATE_PYTHON=python)
-  skip_if(python == "", "python is not installed")
-
-  bundleTempDir <- makeShinyBundleTempDir("reticulated rmd", "test-reticulate-rmds", "implicit.Rmd")
-  on.exit(unlink(bundleTempDir, recursive = TRUE))
-
-  lockfile <- file.path(bundleTempDir, "packrat/packrat.lock")
-  deps <- packrat:::readLockFilePackages(lockfile)
-  expect_true("reticulate" %in% names(deps))
-
-  manifest <- jsonlite::fromJSON(file.path(bundleTempDir, "manifest.json"))
-  expect_equal(manifest$metadata$appmode, "rmd-static")
-  expect_equal(manifest$metadata$primary_rmd, "implicit.Rmd")
-  expect_true(file.exists(file.path(bundleTempDir, manifest$python$package_manager$package_file)))
+  Sys.setenv(RETICULATE_PYTHON="/usr/local/bin/python")
+  expect_equal(getPython(NULL), "/usr/local/bin/python")
   Sys.unsetenv("RETICULATE_PYTHON")
 })
+
+test_that("getPython handles null python and empty RETICULATE_PYTHON", {
+  skip_on_cran()
+
+  Sys.unsetenv("RETICULATE_PYTHON")
+  expect_equal(getPython(NULL), NULL)
+})
+
+test_that("getPython expands paths", {
+  skip_on_cran()
+
+  result <- getPython("~/bin/python")
+  expect_true(result != "~/bin/python")
+  expect_match(result, "*/bin/python")
+})
+
+test_that("getPythonForTarget honors rsconnect.python.enabled = FALSE", {
+  skip_on_cran()
+
+  options(rsconnect.python.enabled = FALSE)
+  result <- getPythonForTarget("/usr/bin/python", list(server="shinyapps.io"))
+  expect_equal(result, NULL)
+  options(rsconnect.python.enabled = NULL)
+})
+
+test_that("getPythonForTarget honors rsconnect.python.enabled = TRUE", {
+  skip_on_cran()
+
+  options(rsconnect.python.enabled = TRUE)
+  result <- getPythonForTarget("/usr/bin/python", list(server="shinyapps.io"))
+  expect_equal(result, "/usr/bin/python")
+  options(rsconnect.python.enabled = NULL)
+})
+
+test_that("getPythonForTarget defaults to enabled for Connect", {
+  skip_on_cran()
+
+  result <- getPythonForTarget("/usr/bin/python", list(server="connect.example.com"))
+  expect_equal(result, "/usr/bin/python")
+})
+
+test_that("getPythonForTarget defaults to disabled for shinyapps.io", {
+  skip_on_cran()
+
+  result <- getPythonForTarget("/usr/bin/python", list(server="shinyapps.io"))
+  expect_equal(result, NULL)
+})
